searchData={"items":[{"type":"module","title":"ElementTui","doc":"Main interface to the ElementTui library, for running a terminal user interface (TUI). Functions in this module allow parsing\nelements and rendering them to the screen. The function `ElementTui.run_loop/3` is a good starting point for running a TUI loop.\n\nTo see the type of elements that can be rendered, check the `ElementTui.Element` module documentation and struct. Also check the\nexamples repository: [https://codeberg.org/edwinvanl/elementtui_examples](https://codeberg.org/edwinvanl/elementtui_examples)","ref":"ElementTui.html"},{"type":"function","title":"ElementTui.clear/0","doc":"Clear the terminal","ref":"ElementTui.html#clear/0"},{"type":"function","title":"ElementTui.height/0","doc":"The height of the terminal","ref":"ElementTui.html#height/0"},{"type":"function","title":"ElementTui.present/0","doc":"Draw the content to the terminal","ref":"ElementTui.html#present/0"},{"type":"function","title":"ElementTui.render/6","doc":"Render the passed elements to a window starting at column x and row y, with total width and height\n\nWill clear the region before rendering.","ref":"ElementTui.html#render/6"},{"type":"function","title":"ElementTui.run_loop/3","doc":"Create a loop for your TUI. Allows passing along state and a function. The function will be called with the state and the event.\n\nAlso possible to pass a timeout, which will be used for polling.","ref":"ElementTui.html#run_loop/3"},{"type":"function","title":"ElementTui.width/0","doc":"The width of the terminal","ref":"ElementTui.html#width/0"},{"type":"module","title":"ElementTui.Application","doc":"Opens a window (tb_init) and kills it on shutdown (tb_shutdown)","ref":"ElementTui.Application.html"},{"type":"module","title":"ElementTui.Element","doc":"Elements are the core of the TUI layout. They are composable so that you can build complex layouts from simple elements.\n\n```\n# Create a text element with width 10\nElement.text(\"Hello\") |> Element.width(10)\n```","ref":"ElementTui.Element.html"},{"type":"function","title":"ElementTui.Element.background_colour/2","doc":"","ref":"ElementTui.Element.html#background_colour/2"},{"type":"function","title":"ElementTui.Element.blank/0","doc":"","ref":"ElementTui.Element.html#blank/0"},{"type":"function","title":"ElementTui.Element.blank_line/0","doc":"Create a blank line.","ref":"ElementTui.Element.html#blank_line/0"},{"type":"function","title":"ElementTui.Element.bold/1","doc":"","ref":"ElementTui.Element.html#bold/1"},{"type":"function","title":"ElementTui.Element.border/1","doc":"","ref":"ElementTui.Element.html#border/1"},{"type":"function","title":"ElementTui.Element.center/1","doc":"","ref":"ElementTui.Element.html#center/1"},{"type":"function","title":"ElementTui.Element.colour/2","doc":"","ref":"ElementTui.Element.html#colour/2"},{"type":"function","title":"ElementTui.Element.cursor/2","doc":"","ref":"ElementTui.Element.html#cursor/2"},{"type":"function","title":"ElementTui.Element.dim/1","doc":"","ref":"ElementTui.Element.html#dim/1"},{"type":"function","title":"ElementTui.Element.focus/1","doc":"","ref":"ElementTui.Element.html#focus/1"},{"type":"function","title":"ElementTui.Element.hbox/1","doc":"","ref":"ElementTui.Element.html#hbox/1"},{"type":"function","title":"ElementTui.Element.height/3","doc":"","ref":"ElementTui.Element.html#height/3"},{"type":"function","title":"ElementTui.Element.hfill/1","doc":"","ref":"ElementTui.Element.html#hfill/1"},{"type":"function","title":"ElementTui.Element.invert_colour/1","doc":"","ref":"ElementTui.Element.html#invert_colour/1"},{"type":"function","title":"ElementTui.Element.layerbox/1","doc":"Plot multiple layers on top of each other. Ensures that the layers are drawn in the correct order.","ref":"ElementTui.Element.html#layerbox/1"},{"type":"function","title":"ElementTui.Element.margin/2","doc":"","ref":"ElementTui.Element.html#margin/2"},{"type":"function","title":"ElementTui.Element.pad/1","doc":"","ref":"ElementTui.Element.html#pad/1"},{"type":"function","title":"ElementTui.Element.render/1","doc":"","ref":"ElementTui.Element.html#render/1"},{"type":"function","title":"ElementTui.Element.style/2","doc":"","ref":"ElementTui.Element.html#style/2"},{"type":"function","title":"ElementTui.Element.text/1","doc":"","ref":"ElementTui.Element.html#text/1"},{"type":"function","title":"ElementTui.Element.text_line/1","doc":"Similar to Element.text, but will assume the text is a single line and does not contain any newlines.\n\nThis is useful for creating elements that are not wrapped and results in higher performance.","ref":"ElementTui.Element.html#text_line/1"},{"type":"function","title":"ElementTui.Element.vbox/2","doc":"Opts can contain scroll: true","ref":"ElementTui.Element.html#vbox/2"},{"type":"function","title":"ElementTui.Element.vfill/1","doc":"","ref":"ElementTui.Element.html#vfill/1"},{"type":"function","title":"ElementTui.Element.width/2","doc":"","ref":"ElementTui.Element.html#width/2"},{"type":"function","title":"ElementTui.Element.wrap/1","doc":"","ref":"ElementTui.Element.html#wrap/1"},{"type":"module","title":"ElementTui.Key","doc":"","ref":"ElementTui.Key.html"},{"type":"function","title":"ElementTui.Key.key/1","doc":"","ref":"ElementTui.Key.html#key/1"},{"type":"module","title":"ElementTui.Parser","doc":"","ref":"ElementTui.Parser.html"},{"type":"function","title":"ElementTui.Parser.calculate_dim/3","doc":"","ref":"ElementTui.Parser.html#calculate_dim/3"},{"type":"function","title":"ElementTui.Parser.parse/5","doc":"","ref":"ElementTui.Parser.html#parse/5"},{"type":"function","title":"ElementTui.Parser.wrap_text/3","doc":"Wraps the given `text` to fit within the specified `max_width` and `approx_height`.\n\nThis function takes a string of text and wraps it to fit within the specified\nmaximum width. The text is preferentially wrapped at word boundaries. If sentences\ninclude very long words they will be broken at the boundary instead.\n\nIf the text cannot be wrapped to fit within the specified `approx_height`, it will\nbe truncated instead. In that case the number of lines returned will always be more\nthan the specified `approx_height`.","ref":"ElementTui.Parser.html#wrap_text/3"},{"type":"function","title":"Parameters - ElementTui.Parser.wrap_text/3","doc":"- `text` (binary) - The text to be wrapped.\n  - `max_width` (integer) - The maximum width (in characters) for each line.\n  - `approx_height` (integer) - The approximate max height (in lines) for the wrapped text.","ref":"ElementTui.Parser.html#wrap_text/3-parameters"},{"type":"function","title":"Examples - ElementTui.Parser.wrap_text/3","doc":"iex> wrap_text(\"Lorem ipsum dolor sit amet, consectetur adipiscing elit.\", 30, 3)\n    [[\"Lorem ipsum dolor sit amet,\"], [\"consectetur adipiscing elit.\"]]","ref":"ElementTui.Parser.html#wrap_text/3-examples"},{"type":"module","title":"ElementTui.Readline","doc":"Module to implement a basic input handler. Supports basic completions. Example of its usage is available on [codeberg](https://codeberg.org/edwinvanl/elementtui_examples) in the Todo example (todo.ex).","ref":"ElementTui.Readline.html"},{"type":"function","title":"ElementTui.Readline.handle/2","doc":"","ref":"ElementTui.Readline.html#handle/2"},{"type":"function","title":"ElementTui.Readline.new/1","doc":"","ref":"ElementTui.Readline.html#new/1"},{"type":"function","title":"ElementTui.Readline.to_element/1","doc":"","ref":"ElementTui.Readline.html#to_element/1"},{"type":"function","title":"ElementTui.Readline.to_string/1","doc":"","ref":"ElementTui.Readline.html#to_string/1"},{"type":"module","title":"ElementTui.Style","doc":"","ref":"ElementTui.Style.html"},{"type":"function","title":"ElementTui.Style.colour/1","doc":"","ref":"ElementTui.Style.html#colour/1"},{"type":"function","title":"ElementTui.Style.colours/0","doc":"","ref":"ElementTui.Style.html#colours/0"},{"type":"function","title":"ElementTui.Style.style/1","doc":"","ref":"ElementTui.Style.html#style/1"},{"type":"function","title":"ElementTui.Style.styles/0","doc":"","ref":"ElementTui.Style.html#styles/0"},{"type":"module","title":"ElementTui.TermBox2Ex","doc":"Thin wrapper around the termbox2 C library. In general a user should not need to use this directly, but instead use the main ElementTui module.","ref":"ElementTui.TermBox2Ex.html"},{"type":"function","title":"ElementTui.TermBox2Ex.clear/0","doc":"","ref":"ElementTui.TermBox2Ex.html#clear/0"},{"type":"function","title":"ElementTui.TermBox2Ex.clear_region/4","doc":"","ref":"ElementTui.TermBox2Ex.html#clear_region/4"},{"type":"function","title":"ElementTui.TermBox2Ex.ex_start/0","doc":"","ref":"ElementTui.TermBox2Ex.html#ex_start/0"},{"type":"function","title":"ElementTui.TermBox2Ex.ex_stop/0","doc":"","ref":"ElementTui.TermBox2Ex.html#ex_stop/0"},{"type":"function","title":"ElementTui.TermBox2Ex.height/0","doc":"","ref":"ElementTui.TermBox2Ex.html#height/0"},{"type":"function","title":"ElementTui.TermBox2Ex.hide_cursor/0","doc":"","ref":"ElementTui.TermBox2Ex.html#hide_cursor/0"},{"type":"function","title":"ElementTui.TermBox2Ex.load_nifs/0","doc":"","ref":"ElementTui.TermBox2Ex.html#load_nifs/0"},{"type":"function","title":"ElementTui.TermBox2Ex.poll/1","doc":"","ref":"ElementTui.TermBox2Ex.html#poll/1"},{"type":"function","title":"ElementTui.TermBox2Ex.present/0","doc":"","ref":"ElementTui.TermBox2Ex.html#present/0"},{"type":"function","title":"ElementTui.TermBox2Ex.puts/5","doc":"","ref":"ElementTui.TermBox2Ex.html#puts/5"},{"type":"function","title":"ElementTui.TermBox2Ex.set_cursor/2","doc":"","ref":"ElementTui.TermBox2Ex.html#set_cursor/2"},{"type":"function","title":"ElementTui.TermBox2Ex.so_contents/0","doc":"","ref":"ElementTui.TermBox2Ex.html#so_contents/0"},{"type":"function","title":"ElementTui.TermBox2Ex.width/0","doc":"","ref":"ElementTui.TermBox2Ex.html#width/0"},{"type":"module","title":"ElementTui.Tui","doc":"This genserver will be started by the application. It will also handle drawing, in order to make sure we write single threaded. In general a user should not need to use this directly, but instead use the main ElementTui module.","ref":"ElementTui.Tui.html"},{"type":"function","title":"ElementTui.Tui.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElementTui.Tui.html#child_spec/1"},{"type":"function","title":"ElementTui.Tui.clear/0","doc":"","ref":"ElementTui.Tui.html#clear/0"},{"type":"function","title":"ElementTui.Tui.clear_region/4","doc":"","ref":"ElementTui.Tui.html#clear_region/4"},{"type":"function","title":"ElementTui.Tui.poll/1","doc":"","ref":"ElementTui.Tui.html#poll/1"},{"type":"function","title":"ElementTui.Tui.present/0","doc":"","ref":"ElementTui.Tui.html#present/0"},{"type":"function","title":"ElementTui.Tui.puts/5","doc":"","ref":"ElementTui.Tui.html#puts/5"},{"type":"function","title":"ElementTui.Tui.start_link/1","doc":"","ref":"ElementTui.Tui.html#start_link/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}